@@ -1,7 +1,7 @@
 use v6;
 use fatal;
 
-unit class Getopt::Long:ver<0.1.6>;
+unit class Getopt::Long:ver<0.1.7>;
 
 role Exceptional is CORE::Exception {
 }
@@ -384,7 +384,7 @@ method get-options(Getopt::Long:D: @args is copy, :%hash, :named-anywhere(:$perm
 			when X::Str::Numeric {
 				$_ does role :: does Exceptional {
 					method message() {
-						qq{Cannot convert $description "$value" to number: $.reason};
+						qq{Cannot convert $description argument "$value" to number: $.reason};
 					}
 				}
 				.rethrow;
@@ -392,7 +392,7 @@ method get-options(Getopt::Long:D: @args is copy, :%hash, :named-anywhere(:$perm
 			when X::Numeric::CannotConvert {
 				$_ does role :: does Exceptional {
 					method message() {
-						"Cannot convert $description $.source to {$.target // $.target.perl}: $.reason"
+						"Cannot convert $description argument $.source to {$.target // $.target.perl}: $.reason"
 					}
 				}
 				.rethrow;
@@ -484,7 +484,7 @@ method get-options(Getopt::Long:D: @args is copy, :%hash, :named-anywhere(:$perm
 		}
 	}
 	@$write-args = @list if $write-args;
-	state Str @labels = <first second third fourth fifth sixth seventh eighth nineth tenth>;
+	state Str @labels = flat <first second third fourth fifth sixth seventh eighth nineth tenth some> ... *;
 	my &fallback-converter = $compat-positional ?? &maybe-converter !! &null-converter;
 	my @converters = |@!positionals, &fallback-converter, *;
 	@list = (@labels Z @list Z @converters).map: { wrap-exceptions(|@^args) }
@@ -565,9 +565,14 @@ Getopt::Long
 
   use Getopt::Long;
   get-options("length=i" => my $length, # numeric
-              "file=s"   => my $file    # string
+              "file=s"   => my $file,   # string
               "verbose"  => my $verbose); # flag
 
+  use Getopt::Long;
+  my $options = get-options("length=i", # numeric
+                            "file=s",   # string
+                            "verbose"); # flag
+
 or
 
  use Getopt::Long;
@@ -740,7 +745,7 @@ insert a double dash C<--> on the command line:
     --size 24 -- --all
 
 In this example, C<--all> will I<not> be treated as an option, but
-passed to the program unharmed, in C<@ARGV>.
+passed to the program unharmed, in C<@*ARGS>.
 
 =head2 Options with values
 
@@ -1042,7 +1047,7 @@ arguments:
 =head2 Parsing options from an arbitrary array
 
 By default, get-options parses the options that are present in the
-global array C<@*ARGV>. A special entry C<get-options-from> can be
+global array C<@*ARGS>. A special entry C<get-options-from> can be
 used to parse options from an arbitrary array.
 
     use Getopt::Long;
